@@ -450,14 +450,21 @@ def preprocess_face(img, target_size=(224, 224), grayscale = False, enforce_dete
 	
 	#img might be path, base64 or numpy array. Convert it to numpy whatever it is.
 	img = load_image(img)
+	base_img = img.copy()
+	
+	img = detect_face(img = img, detector_backend = detector_backend, grayscale = grayscale, enforce_detection = enforce_detection)
 	
 	#--------------------------
 	
-	#we will align base image instead of detected face not have black pixels
-	
-	img = detect_face(img = img, detector_backend = detector_backend, grayscale = grayscale, enforce_detection = enforce_detection)
-	img = align_face(img = img, detector_backend = detector_backend)
-	
+	if img.shape[0] > 0 and img.shape[1] > 0:
+		img = align_face(img = img, detector_backend = detector_backend)
+	else:
+		
+		if enforce_detection == True:
+			raise ValueError("Detected face shape is ", img.shape,". Consider to set enforce_detection argument to False.")
+		else: #restore base image 
+			img = base_img.copy()
+		
 	#--------------------------
 	
 	#post-processing
